@@ -30,7 +30,11 @@ where
         if let Some(parent) = location.parent() {
             fs::create_dir_all(parent)?;
         }
-        if let Ok(new) = OpenOptions::new().create_new(true).open(&location) {
+        if let Ok(new) = OpenOptions::new()
+            .write(true)
+            .create_new(true)
+            .open(&location)
+        {
             debug!("Populating new file at {}", location.display());
             serde_json::to_writer_pretty(new, &default)?;
         }
